from .housing_market import HousingMarketModel

def run_simulation(steps=30):
    """ 运行 ABM 住房市场模拟 """
    model = HousingMarketModel(50)
    for _ in range(steps):
        model.step()
    return model
