from setuptools import setup, find_packages

setup(
    name="SIM4CNHousing",
    version="0.1.0",
    description="中国住房市场的代理建模 (ABM) 模拟",
    author="你的名字",
    author_email="你的邮箱@example.com",
    packages=find_packages(),
    install_requires=[
        "numpy",
        "matplotlib",
        "streamlit",
        "mesa"
    ],
    entry_points={
        "console_scripts": [
            "sim4cnhousing-visualization=SIM4CNHousing.visualization:run_streamlit_visualization",
            "sim4cnhousing-simulation=SIM4CNHousing.simulation:run_simulation"
        ]
    }
)
